@@ -31,6 +31,8 @@
 
 #include <gmenu-tree.h>
 
+#include <libpanel-util/panel-error.h>
+
 #include "applet.h"
 #include "panel-widget.h"
 #include "panel-util.h"
@@ -41,7 +43,7 @@
 #include "panel-a11y.h"
 #include "panel-icon-names.h"
 
-G_DEFINE_TYPE (PanelMenuButton, panel_menu_button, BUTTON_TYPE_WIDGET);
+G_DEFINE_TYPE (PanelMenuButton, panel_menu_button, BUTTON_TYPE_WIDGET)
 
 #define PANEL_MENU_BUTTON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_MENU_BUTTON, PanelMenuButtonPrivate))
 
